class Collection < ActiveRecord::Base
  include Reviewable
  include Sociable
  include Followable
  include Scoreable
  include Thumbnailable

  has_many :collection_items, as: :collectionable, dependent: :destroy
  has_many :collections, through: :collection_items, source: :collectionable, source_type: 'Collection'
  has_many :learning_objects, through: :collection_items, source: :collectionable, source_type: 'LearningObject'
  has_many :collection_items

  belongs_to :owner, polymorphic: true

  validates_presence_of :name, :owner
  validates_inclusion_of :privacy, in: %w(public private), message: "Privacy must be public or private"

  scope :from_user, ->(user) { where(owner: user) }

  searchkick language: 'brazilian', match: :word_start, searchable: [:name, :description, :author]

  def search_data
    {
      name: name,
      description: description,
      privacy: privacy,
      owner: owner.name,
      score: score,
      created_at: created_at,
    }
  end

  def owner?(candidate)
    owner == candidate
  end

  def private?
    privacy == 'private'
  end

  ## score methods
  def user_category
    owner.try('user_category')
  end
end
